whatr_synopsis: What a synopsis?

View source: R/whatr-synopsis.R

whatr_synopsisR Documentation

What a synopsis?

Description

This is an overview containing various summary statistics of a game.

Usage

whatr_synopsis(game)

Arguments

game

One of four types of input, all passed to whatr_html():

  1. A numeric game ID.

  2. Either a 'showgame' or 'showscores' HTML document.

  3. A show number character starting with "#".

  4. An air date like "yyyy-mm-dd".

Format

A tibble with (usually) 3 row and 5 variables:

name

The contestant's given name.

coryat

Score if all wagering is disregarded.

final

Final score after Double Jeopardy.

right

Number of correct answers.

wrong

Number of incorrect answers.

Value

A tidy tibble of clue text.

Examples

whatr_synopsis(game = 6304)

kiernann/whatr documentation built on April 16, 2022, 9:55 p.m.