whatr_board: What is the board?

View source: R/whatr-data.R

whatr_boardR Documentation

What is the board?

Description

This grid contains all the categories, clues, and answers in a game.

Usage

whatr_board(game)

Arguments

game

One of four types of input, all passed to whatr_html():

  1. A numeric game ID.

  2. Either a 'showgame' or 'showscores' HTML document.

  3. A show number character starting with "#".

  4. An air date like "yyyy-mm-dd".

Format

A tibble with (usually) 61 rows and 4 variables:

round

The round a clue is chosen.

col

The column position left-to-right.

row

The row position top-to-bottom.

n

The order of clue chosen.

category

Category title, often humorous or with instructions.

clue

The clue read to the contestants.

answer

The correct answer to a clue.

Value

A tidy tibble of clue text.

Examples

whatr_board(game = 6304)

kiernann/whatr documentation built on April 16, 2022, 9:55 p.m.